/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package org.objectweb.dream.control.activity.task;

import java.util.Map;

/**
 * A control interface to manage tasks.
 */
public interface TaskManagerController
{

  /**
   * Registers a new task.
   * 
   * @param task the task to be registered.
   * @param hints additionnal parameters.
   * @return an interface that can used to control the registered task (may be
   *         <code>null</code> if no control is available on the task).
   * @throws IllegalTaskException if an error occurs.
   */
  Object registerTask(Task task, Map hints) throws IllegalTaskException;

  /**
   * Unregisters the specified task.
   * 
   * @param task the task to be removed.
   * @throws IllegalTaskException if an error occurs.
   */
  void unregisterTask(Task task) throws IllegalTaskException;

  /**
   * Interrupt the specified task. an interrupted task, is no more executed. The
   * givent <code>listener</code> is notified when the task is inactivated.
   * The inactivated task should then be unregistered from the activity manager.
   * 
   * @param task the task to interrupt.
   * @param listener a listener to notify. Can be <code>null</code>.
   * @throws IllegalTaskException if the given task is unknown.
   */
  void interruptTask(Task task, TaskStoppedListener listener)
      throws IllegalTaskException;

  /**
   * Returns the tasks that have been registered.
   * 
   * @return the tasks that have been registered.
   */
  Task[] getTasks();
}